@@ -13,6 +13,7 @@ if(test_code[1].find("// STDIN") >= 0):
 else:
     test_in = ""
 
+os.system("chmod +x " + sys.argv[1])
 (n,out,err) = os.popen3("./" + sys.argv[1])
 		
 if(test_in != ""):
@@ -42,7 +43,7 @@ outf.write(test_code[0])
 outf.write("// Returns: 0\n")
 outf.write("// STDIN:" + test_in + "\n")
 outf.write("// STDOUT:" + sanitize("".join(out.readlines()).rstrip()) + "\n")
-outf.write("// STDERR:" + sanitize("".join(out.readlines()).rstrip()) + "\n")
+outf.write("// STDERR:" + sanitize("".join(err.readlines()).rstrip()) + "\n")
 
 if(test_in != ""):
 	outf.write("".join(test_code[2:]))
